﻿using LifeLogApp.Classes;
using LifeLogApp.Services;
using LifeLogApp.ViewModel;
using System.Reflection;
using System.Runtime.CompilerServices;

namespace LifeLogApp;

public partial class App : Application
{
    // https://learn.microsoft.com/en-us/dotnet/maui/

    Serilog.ILogger logger;
    UploadService appUploadService;
    MainViewModel mainViewModel;

    public App(Serilog.ILogger logger, UploadService uploadService, MainViewModel mainViewModel)
    {
        this.logger = logger;
        this.mainViewModel = mainViewModel;

        InitializeComponent();

        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));

        this.appUploadService = uploadService;

        MainPage = new AppShell();
    }

    protected override async void OnStart()
    {
        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));
        base.OnStart();

        await MainThread.InvokeOnMainThreadAsync(async () => await AppHelper.RequestAllPermissionsAsync());
    }

    protected override void OnSleep()
    {
        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));
        base.OnSleep();
    }

    protected override void OnResume()
    {
        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));
        base.OnResume();
    }

    protected override Window CreateWindow(IActivationState activationState)
    {
        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));
        return base.CreateWindow(activationState);
    }

    protected override void OnAppLinkRequestReceived(Uri uri)
    {
        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));
        base.OnAppLinkRequestReceived(uri);
    }

    protected override void OnBindingContextChanged()
    {
        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));
        base.OnBindingContextChanged();
    }

    protected override void OnChildAdded(Element child)
    {
        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));
        base.OnChildAdded(child);
    }

    protected override void OnChildRemoved(Element child, int oldLogicalIndex)
    {
        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));
        base.OnChildRemoved(child, oldLogicalIndex);
    }

    protected override void OnHandlerChanged()
    {
        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));
        base.OnHandlerChanged();
    }

    protected override void OnHandlerChanging(HandlerChangingEventArgs args)
    {
        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));
        base.OnHandlerChanging(args);
    }

    protected override void OnParentChanged()
    {
        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));
        base.OnParentChanged();
    }

    protected override void OnParentChanging(ParentChangingEventArgs args)
    {
        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));
        base.OnParentChanging(args);
    }

    protected override void OnParentSet()
    {
        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));
        base.OnParentSet();
    }

    protected override void OnPropertyChanged([CallerMemberName] string propertyName = null)
    {
        logger.Verbose("{Method}: Start, PropertyName={PropertyName}", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()), propertyName);
        base.OnPropertyChanged(propertyName);
    }

    protected override void OnPropertyChanging([CallerMemberName] string propertyName = null)
    {
        logger.Verbose("{Method}: Start, PropertyName={PropertyName}", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()), propertyName);
        base.OnPropertyChanging(propertyName);
    }

}
