﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;

namespace LifeLogApp.Classes
{
    public static class AppHelper
    {
        public static bool IsAndroid() => DeviceInfo.Current.Platform == DevicePlatform.Android;
        public static bool IsiOS() => DeviceInfo.Current.Platform == DevicePlatform.iOS;

        public static string AppPathUploadEvents
        {
            get
            {
                var photoUploadPath = Path.Combine(FileSystem.AppDataDirectory, "Upload", "Events");
                Directory.CreateDirectory(photoUploadPath);
                return photoUploadPath;
            }
        }

        /// <summary>
        /// Usage: await MainThread.InvokeOnMainThreadAsync(async () => await AppHelper.RequestAllPermissionsAsync())
        /// MAUI Docs: https://learn.microsoft.com/en-us/dotnet/maui/platform-integration/appmodel/permissions?view=net-maui-7.0
        /// </summary>
        /// <returns></returns>
        public static async Task RequestAllPermissionsAsync()
        {
            await Permissions.RequestAsync<Permissions.Camera>();
            await Permissions.RequestAsync<Permissions.Microphone>();
            await Permissions.RequestAsync<Permissions.StorageRead>();
            await Permissions.RequestAsync<Permissions.StorageWrite>();
            await Permissions.RequestAsync<Permissions.LocationWhenInUse>();
        }

        /// <summary>
        /// Usage: AppHelper.BuildFullMethodName(System.Reflection.MethodBase.GetCurrentMethod())
        /// </summary>
        /// <param name="method"></param>
        /// <returns></returns>
        public static string BuildFullMethodName(MethodBase method)
        {
            return $"{method.ReflectedType.FullName}.{method.Name}({string.Join(",", method.GetParameters().Select(o => $"{o.ParameterType} {o.Name}").ToArray())})";
        }
    }
}
