﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace LifeLogApp.Classes
{
    public static class MediaHelper
    {
        public static async Task<string> TakePhotoAsync()
        {
            // https://docs.microsoft.com/en-us/dotnet/maui/platform-integration/device-media/picker?tabs=android

            if (await Permissions.CheckStatusAsync<Permissions.Camera>() != PermissionStatus.Granted)
            {
                if (Permissions.ShouldShowRationale<Permissions.LocationWhenInUse>())
                {
                    // Prompt the user with additional information as to why the permission is needed
                    await Application.Current.MainPage.DisplayAlert(
                        "Needed permission",
                        "This application need permission to LocationWhenInUse. Goto settings and turn on LocationWhenInUse for this appliction.",
                        "Ok");
                }

                if (await Permissions.RequestAsync<Permissions.Camera>() != PermissionStatus.Granted)
                    return null;

                //await MainThread.InvokeOnMainThreadAsync(async () =>
                //{
                //    await Application.Current.MainPage.DisplayAlert("Error", "No Camera", "Ok");
                //});

            }

            FileResult photo = await MediaPicker.Default.CapturePhotoAsync();

            if (photo != null)
            {
                // save the file into local storage
                string localFilePath = Path.Combine(AppHelper.AppPathUploadEvents, $"{Guid.NewGuid()}{Path.GetExtension(photo.FileName)}");

                using Stream sourceStream = await photo.OpenReadAsync();
                using FileStream localFileStream = File.OpenWrite(localFilePath);

                await sourceStream.CopyToAsync(localFileStream);

                return localFilePath;
            }

            return null;
        }

        public static async Task<string> TakeVideoAsync()
        {
            if (MediaPicker.Default.IsCaptureSupported)
            {
                FileResult video = await MediaPicker.Default.CaptureVideoAsync();

                if (video != null)
                {
                    // save the file into local storage
                    string localFilePath = Path.Combine(AppHelper.AppPathUploadEvents, $"{Guid.NewGuid()}{Path.GetExtension(video.FileName)}");

                    using Stream sourceStream = await video.OpenReadAsync();
                    using FileStream localFileStream = File.OpenWrite(localFilePath);

                    await sourceStream.CopyToAsync(localFileStream);

                    return localFilePath;
                }
            }

            return null;
        }
    }
}
