﻿using Microsoft.AppCenter;
using Microsoft.AppCenter.Analytics;
using Microsoft.AppCenter.Crashes;
using LifeLogApp.Services;
using System.Reflection;
using LifeLogApp.Interfaces;
using LifeLogApp.ViewModel;
using Microsoft.Extensions.Logging;
using Serilog;
using DevExpress.Maui;
using Microsoft.Maui.Controls.Compatibility.Hosting;

namespace LifeLogApp;

public static class MauiProgram
{
    public static MauiApp CreateMauiApp()
    {
        Preferences.Set("DoUpload", false);

        var builder = MauiApp.CreateBuilder();
        builder
            .UseMauiApp<App>()
            .UseDevExpress()
            .ConfigureFonts(fonts =>
            {
                fonts.AddFont("OpenSans-Regular.ttf", "OpenSansRegular");
                fonts.AddFont("OpenSans-Semibold.ttf", "OpenSansSemibold");
            })
            .UseMauiCompatibility();

        #region "Serilog"

        // https://github.com/datalust/serilog-sinks-seq
        // https://github.com/serilog/serilog/wiki/Configuration-Basics
        // https://learn.microsoft.com/en-us/dotnet/maui/platform-integration/appmodel/app-information?view=net-maui-7.0&tabs=windows
#if DEBUG
        builder.Services.AddSingleton(Serilog.ILogger (e) => new Serilog.LoggerConfiguration()
                                                                    .WriteTo.Seq("http://seq.unipoint.se:15341")
                                                                    .Enrich.WithProperty("App", AppInfo.Current.Name)
                                                                    .Enrich.WithProperty("AppVersion", AppInfo.Current.VersionString)
                                                                    .Enrich.WithProperty("AppPackageName", AppInfo.Current.PackageName)
                                                                    .Enrich.WithProperty("AppBuildString", AppInfo.Current.BuildString)
                                                                    .Enrich.WithProperty("DevicePlatform", DeviceInfo.Platform)
                                                                    .Enrich.WithProperty("DeviceName", DeviceInfo.Name)
                                                                    .Enrich.WithProperty("DeviceModel", DeviceInfo.Model)
                                                                    .Enrich.WithProperty("DeviceManufacturer", DeviceInfo.Manufacturer)
                                                                    .Enrich.WithProperty("DeviceOSVersion", DeviceInfo.VersionString)
                                                                    .Enrich.WithProperty("DeviceIdiom", DeviceInfo.Idiom)
                                                                    .Enrich.WithProperty("DeviceType", DeviceInfo.DeviceType)
                                                                    .Enrich.WithProperty("DeviceId", (new GetDeviceInfo()).GetDeviceID())
                                                                    .Enrich.FromLogContext()
                                                                    .MinimumLevel.Verbose()
                                                                    .CreateLogger());


#else
        builder.Services.AddSingleton(Serilog.ILogger (e) => new LoggerConfiguration().CreateLogger());
#endif

        #endregion

        // Low level services
        builder.Services.AddTransient(IAppDeviceInfo (e) => new GetDeviceInfo());
        builder.Services.AddSingleton<ConnectivityService>();
        builder.Services.AddTransient<GeoService>();

        // Background workers
        builder.Services.AddSingleton<UploadService>();

        // View Models
        builder.Services.AddSingleton<MainViewModel>();

        // Pages
        builder.Services.AddSingleton<CapturePage>();
        builder.Services.AddSingleton<CaptureDevX>();
        builder.Services.AddSingleton<BindingTest>();
        builder.Services.AddSingleton<SettingsPage>();
        builder.Services.AddSingleton<ControlDemoPage>();

        // Shell Routes
        builder.Services.AddSingleton<NewPage1>();

        return builder.Build();
    }
}
