﻿using LifeLogApp.Classes;
using RestSharp;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;

namespace LifeLogApp.Services;

public class UploadService
{
    Serilog.ILogger logger;
    GeoService geoService;

    public Task task;
    public CancellationToken cancellationToken;

    public UploadService(Serilog.ILogger logger, GeoService geoService)
    {
        this.logger = logger;
        this.geoService = geoService;

        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));

        task = Task.Run(() => Run(), cancellationToken);
    }

    public async void Run()
    {
        logger.Verbose("{Method}: Start", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));

        while(!cancellationToken.IsCancellationRequested)
        {
            var doUpload = Preferences.Get("DoUpload", false);
            logger.Verbose(
                "{Method}: DoUpload={DoUpload}",
                AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()),
                doUpload);
            if(doUpload)
            {
                logger.Verbose("{Method}: While", AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()));

                var currentLocation = await geoService.GetCurrentLocationAsync();

                var mediaToUpload = Directory.GetFiles(
                    AppHelper.AppPathUploadEvents,
                    "*.*",
                    SearchOption.AllDirectories);
                foreach(var m in mediaToUpload)
                {
                    logger.Verbose(
                        "{Method}: Start Upload Media {Media}",
                        AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()),
                        m);

                    var client = new RestClient(
                        $"https://my.unipoint.se/LifeLog_Dev/api/File?name={System.IO.Path.GetFileName(m)}");
                    client.Timeout = -1;
                    var request = new RestRequest(Method.POST);
                    request.AddHeader("ApiKey", "xyz");
                    request.AddFile("", m);

                    var fullUrl = client.BuildUri(request);
                    logger.Debug("FullUrl={FullUrl}", fullUrl);

                    IRestResponse response = client.Execute(request);
                    logger.Debug("Response={StatusCode}, {Content}", response.StatusCode, response.Content);

                    if(response.IsSuccessful)
                    {
                        logger.Verbose(
                            "{Method}: Media Uploaded OK {Media}",
                            AppHelper.BuildFullMethodName(MethodBase.GetCurrentMethod()),
                            m);
                        try
                        {
                            File.Delete(m);
                        } catch(Exception ex)
                        {
                            logger.Error(ex, "File.Delete");
                        }
                    }
                }
            }

            await Task.Delay(5000);
        }
    }
}
